==> nextcloud-24.0.9.tgz: nextcloud/apps/updatenotification/l10n/de.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Weitere Informationen zur Aktualisierung.",
    "Channel updated" : "Kanal aktualisiert",
    "Web updater is disabled" : "Der Web-Updater ist deaktiviert",
    "Update notifications" : "Update-Benachrichtigungen",
    "The update server could not be reached since %d days to check for new updates." : "Der Aktualisierungsserver konnte seit %d Tagen nicht erreicht werden, um auf verfügbare Aktualisierungen zu prüfen.",
    "Please check the Nextcloud and server log files for errors." : "Bitte überprüfe die Server- und Nextcloud-Logdateien auf Fehler.",
    "Update to %1$s is available." : "Aktualisierung auf %1$s ist verfügbar.",
    "Update for {app} to version %s is available." : "Eine Aktualisierung für {app} auf Version %s ist verfügbar.",
    "Update notification" : "Aktualisierungs-Benachrichtigung",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zeigt Benachrichtigungen für Aktualisierungen von Nextcloud an und bietet SSO für den Aktualisierer.",
    "Update" : "Aktualisieren",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Deine installierte Version wird nicht mehr unterstützt. Bitte aktualisiere baldmöglichst auf eine unterstützte Version.",
    "Apps missing compatible version" : "Für diese Apps fehlen kompatible Versionen",
    "View in store" : "Im Store anzeigen",
    "Apps with compatible version" : "Für diese Apps gibt es kompatible Versionen",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachte, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwende stattdessen den Befehlszeilen-Updater!",
    "Open updater" : "Updater öffnen",
    "Download now" : "Jetzt herunterladen",
    "Please use the command line updater to update." : "Verwende zum Aktualisieren den Befehlszeilen-Updater.",
    "What's new?" : "Was ist neu?",
    "The update check is not yet finished. Please refresh the page." : "Die Aktualisierungsprüfung ist noch nicht abgeschlossen. Bitte die Seite neu laden.",
    "Your version is up to date." : "Deine Version ist aktuell.",
    "A non-default update server is in use to be checked for updates:" : "Es wird ein Nicht-Standard-Aktualisierungsserver zum Prüfen auf Aktualisierungen verwendet:",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kannst den Aktualisierungskanal unten ändern, was sich auch auf die Verwaltungsseite der Apps auswirkt. Z. B. werden nach dem Wechsel zum Beta-Kanal dir Beta-App-Updates auf der App-Verwaltungsseite angeboten.",
    "Update channel:" : "Update-Kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Es kann immer auf eine neuere Version aktualisiert werden. Jedoch kann kein Downgrade auf eine stabilere Version erfolgen. ",
    "Notify members of the following groups about available updates:" : "Informiere die Mitglieder der folgenden Gruppen über verfügbare Updates:",
    "Only notifications for app updates are available." : "Benachrichtigungen sind nur für Aktualisierungen von Apps verfügbar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Aktualisierungskanal macht dedizierte Benachrichtigungen für Server Aktualisierungen obsolet.",
    "The selected update channel does not support updates of the server." : "Der gewählte Aktualisierungskanal unterstützt keine Aktualisierungen für Server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Eine neue Version ist verfügbar: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachte, dass das Update nach einer neuen Version erst nach der ersten Hauptversion oder später angezeigt wird. Die Nextcloud GmbH stellt den Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringt manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Updates und Release-Kanälen findest du unter {link}",
    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}",
    "Checking apps for compatible versions" : "Es werden alle Apps auf kompatible Versionen geprüft",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bitte stelle sicher, dass in der \"config.php\"-Datei die Variable <samp>appstoreenabled</samp> nicht auf \"false\" steht.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Die Verbindung zum App-Store konnte nicht aufgebaut werden oder der App-Store hat keine Apps zurück geliefert. Suche selbst nach Updates oder stelle sicher, dass dein Server Zugriff auf das Internet hat und eine Verbindung zum App-Store aufbauen kann. ",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "Für <strong>alle</strong> Apps steht eine kompatible Version zur Verfügung.",
    "View changelog" : "Liste der Änderungen anschauen",
    "Enterprise" : "Version für Unternehmen",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Für den Einsatz in Unternehmen. Stellt immer die neueste Patch-Version bereit, wird jedoch nicht sofort auf die nächste Hauptversion aktualisiert. Diese Aktualisierung wird durchgeführt, sobald die Nextcloud GmbH zusätzliche Vorbereitungen und Tests für umfangreiche und unternehmenskritische Software-Verteilungen durchgeführt hat. Dieser Kanal steht nur Kunden zur Verfügung und enthält das Nextcloud Firmen-Paket .",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Die aktuellste stabile Version. Diese ist für den regelmäßigen Gebrauch geeignet und wird immer auf die letzte Hauptversion aktualisiert.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Eine Vorabversion die einzig zum Testen neuer Funktionen dient, nicht aber für den Einsatz in Produktivumgebungen geeignet ist.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps stehen keine kompatible Versionen zur Verfügung."],
    "Update for %1$s to version %2$s is available." : "Eine Aktualisierung von %1$s auf Version %2$s ist verfügbar."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.10.tgz: nextcloud/apps/updatenotification/l10n/de.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} ist verfügbar. Weitere Informationen zur Aktualisierung.",
    "Channel updated" : "Kanal aktualisiert",
    "Web updater is disabled" : "Der Web-Updater ist deaktiviert",
    "Update notifications" : "Update-Benachrichtigungen",
    "The update server could not be reached since %d days to check for new updates." : "Der Aktualisierungsserver konnte seit %d Tagen nicht erreicht werden, um auf verfügbare Aktualisierungen zu prüfen.",
    "Please check the Nextcloud and server log files for errors." : "Bitte überprüfe die Server- und Nextcloud-Logdateien auf Fehler.",
    "Update to %1$s is available." : "Aktualisierung auf %1$s ist verfügbar.",
    "Update to {serverAndVersion} is available." : "Aktualisierung auf {serverAndVersion} ist verfügbar.",
    "Update for {app} to version %s is available." : "Eine Aktualisierung für {app} auf Version %s ist verfügbar.",
    "Update notification" : "Aktualisierungs-Benachrichtigung",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zeigt Benachrichtigungen für Aktualisierungen von Nextcloud an und bietet SSO für den Aktualisierer.",
    "Update" : "Aktualisieren",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Deine installierte Version wird nicht mehr unterstützt. Bitte aktualisiere baldmöglichst auf eine unterstützte Version.",
    "Apps missing compatible version" : "Für diese Apps fehlen kompatible Versionen",
    "View in store" : "Im Store anzeigen",
    "Apps with compatible version" : "Für diese Apps gibt es kompatible Versionen",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachte, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwende stattdessen den Befehlszeilen-Updater!",
    "Open updater" : "Updater öffnen",
    "Download now" : "Jetzt herunterladen",
    "Please use the command line updater to update." : "Verwende zum Aktualisieren den Befehlszeilen-Updater.",
    "What's new?" : "Was ist neu?",
    "The update check is not yet finished. Please refresh the page." : "Die Aktualisierungsprüfung ist noch nicht abgeschlossen. Bitte die Seite neu laden.",
    "Your version is up to date." : "Deine Version ist aktuell.",
    "A non-default update server is in use to be checked for updates:" : "Es wird ein Nicht-Standard-Aktualisierungsserver zum Prüfen auf Aktualisierungen verwendet:",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kannst den Aktualisierungskanal unten ändern, was sich auch auf die Verwaltungsseite der Apps auswirkt. Z. B. werden nach dem Wechsel zum Beta-Kanal dir Beta-App-Updates auf der App-Verwaltungsseite angeboten.",
    "Update channel:" : "Update-Kanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Es kann immer auf eine neuere Version aktualisiert werden. Jedoch kann kein Downgrade auf eine stabilere Version erfolgen. ",
    "Notify members of the following groups about available updates:" : "Informiere die Mitglieder der folgenden Gruppen über verfügbare Updates:",
    "Only notifications for app updates are available." : "Benachrichtigungen sind nur für Aktualisierungen von Apps verfügbar.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Aktualisierungskanal macht dedizierte Benachrichtigungen für Server Aktualisierungen obsolet.",
    "The selected update channel does not support updates of the server." : "Der gewählte Aktualisierungskanal unterstützt keine Aktualisierungen für Server.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Eine neue Version ist verfügbar: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachte, dass das Update nach einer neuen Version erst nach der ersten Hauptversion oder später angezeigt wird. Die Nextcloud GmbH stellt den Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringt manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Updates und Release-Kanälen findest du unter {link}",
    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}",
    "Checking apps for compatible versions" : "Es werden alle Apps auf kompatible Versionen geprüft",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bitte stelle sicher, dass in der \"config.php\"-Datei die Variable <samp>appstoreenabled</samp> nicht auf \"false\" steht.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Die Verbindung zum App-Store konnte nicht aufgebaut werden oder der App-Store hat keine Apps zurück geliefert. Suche selbst nach Updates oder stelle sicher, dass dein Server Zugriff auf das Internet hat und eine Verbindung zum App-Store aufbauen kann. ",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "Für <strong>alle</strong> Apps steht eine kompatible Version zur Verfügung.",
    "View changelog" : "Liste der Änderungen anschauen",
    "Enterprise" : "Version für Unternehmen",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Für den Einsatz in Unternehmen. Stellt immer die neueste Patch-Version bereit, wird jedoch nicht sofort auf die nächste Hauptversion aktualisiert. Diese Aktualisierung wird durchgeführt, sobald die Nextcloud GmbH zusätzliche Vorbereitungen und Tests für umfangreiche und unternehmenskritische Software-Verteilungen durchgeführt hat. Dieser Kanal steht nur Kunden zur Verfügung und enthält das Nextcloud Firmen-Paket .",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Die aktuellste stabile Version. Diese ist für den regelmäßigen Gebrauch geeignet und wird immer auf die letzte Hauptversion aktualisiert.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Eine Vorabversion die einzig zum Testen neuer Funktionen dient, nicht aber für den Einsatz in Produktivumgebungen geeignet ist.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps stehen keine kompatible Versionen zur Verfügung."],
    "Update for %1$s to version %2$s is available." : "Eine Aktualisierung von %1$s auf Version %2$s ist verfügbar."
},
"nplurals=2; plural=(n != 1);");
